@@ -40,7 +40,7 @@ with 'App::FargateStack::CloudTrail';
 with 'App::FargateStack::CreateStack';
 with 'App::FargateStack::Autoscaling';
 
-with 'App::Benchmark';
+with 'App::BenchmarkRole';
 
 # builder methods
 with 'App::FargateStack::Builder';
@@ -61,7 +61,7 @@ with 'App::FargateStack::Builder::TaskDefinition';
 with 'App::FargateStack::Builder::Utils';
 with 'App::FargateStack::Builder::WafV2';
 
-our $VERSION = '1.0.45';
+our $VERSION = '1.0.46';
 
 use parent qw(CLI::Simple);
 
